/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 8072853
 * @summary SimpleScriptContext used by NashornScriptEngine doesn't completely complies to the spec regarding exception throwing
 * @run testng SimpleScriptContextNameChecksTest
 */

import java.util.List;
import javax.script.*;
import org.testng.annotations.Test;

public class SimpleScriptContextNameChecksTest {
    private List<ScriptEngineFactory> getFactories() {
        return new ScriptEngineManager().getEngineFactories();
    }

    @Test
    public void getAttributeEmptyName() {
        for (ScriptEngineFactory fac : getFactories()) {
            ScriptContext sc = fac.getScriptEngine().getContext();
            String name = fac.getEngineName();
            try {
                sc.getAttribute("", ScriptContext.GLOBAL_SCOPE);
                throw new RuntimeException("no exception for " + name);
            } catch (IllegalArgumentException iae) {
                System.out.println("got " + iae + " as expected for " + name);
            }
        }
    }

    @Test
    public void getAttributeNullName() {
        for (ScriptEngineFactory fac : getFactories()) {
            ScriptContext sc = fac.getScriptEngine().getContext();
            String name = fac.getEngineName();
            try {
                sc.getAttribute(null, ScriptContext.GLOBAL_SCOPE);
                throw new RuntimeException("no exception for " + name);
            } catch (NullPointerException npe) {
                System.out.println("got " + npe + " as expected for " + name);
            }
        }
    }

    @Test
    public void removeAttributeEmptyName() {
        for (ScriptEngineFactory fac : getFactories()) {
            ScriptContext sc = fac.getScriptEngine().getContext();
            String name = fac.getEngineName();
            try {
                sc.removeAttribute("", ScriptContext.GLOBAL_SCOPE);
                throw new RuntimeException("no exception for " + name);
            } catch (IllegalArgumentException iae) {
                System.out.println("got " + iae + " as expected for " + name);
            }
        }
    }

    @Test
    public void removeAttributeNullName() {
        for (ScriptEngineFactory fac : getFactories()) {
            ScriptContext sc = fac.getScriptEngine().getContext();
            String name = fac.getEngineName();
            try {
                sc.removeAttribute(null, ScriptContext.GLOBAL_SCOPE);
                throw new RuntimeException("no exception for " + name);
            } catch (NullPointerException npe) {
                System.out.println("got " + npe + " as expected for " + name);
            }
        }
    }

    @Test
    public void setAttributeEmptyName() {
        for (ScriptEngineFactory fac : getFactories()) {
            ScriptContext sc = fac.getScriptEngine().getContext();
            String name = fac.getEngineName();
            try {
                sc.setAttribute("", "value", ScriptContext.GLOBAL_SCOPE);
                throw new RuntimeException("no exception for " + name);
            } catch (IllegalArgumentException iae) {
                System.out.println("got " + iae + " as expected for " + name);
            }
        }
    }

    @Test
    public void setAttributeNullName() {
        for (ScriptEngineFactory fac : getFactories()) {
            ScriptContext sc = fac.getScriptEngine().getContext();
            String name = fac.getEngineName();
            try {
                sc.setAttribute(null, "value", ScriptContext.GLOBAL_SCOPE);
                throw new RuntimeException("no exception for " + name);
            } catch (NullPointerException npe) {
                System.out.println("got " + npe + " as expected for " + name);
            }
        }
    }

    @Test
    public void getAttributesScopeEmptyName() {
        for (ScriptEngineFactory fac : getFactories()) {
            ScriptContext sc = fac.getScriptEngine().getContext();
            String name = fac.getEngineName();
            try {
                sc.getAttributesScope("");
                throw new RuntimeException("no exception for " + name);
            } catch (IllegalArgumentException iae) {
                System.out.println("got " + iae + " as expected for " + name);
            }
        }
    }

    @Test
    public void getAttributesScopeNullName() {
        for (ScriptEngineFactory fac : getFactories()) {
            ScriptContext sc = fac.getScriptEngine().getContext();
            String name = fac.getEngineName();
            try {
                sc.getAttributesScope(null);
                throw new RuntimeException("no exception for " + name);
            } catch (NullPointerException npe) {
                System.out.println("got " + npe + " as expected for " + name);
            }
        }
    }
}
